/*******************************************************************/
/*      Spool File Thing  --  A.K.A. DSPSPLF                       */
/*      Michael Swenson                                            */
/*                                                                 */
/*  This program uses the cwbOBJ APIs to open a spool file in the  */
/*  AFP spool file viewer.                                         */
/*                                                                 */
/*  INPUT:  The program requires 6 input arguments:                */
/*     System Name - the name of the AS/400 system the splf is on. */
/*     Job Name - the name of the job which created the splf.      */
/*     Job Number - the number of the job which created the splf.  */
/*     Job User - the user profile which owns the splf.            */
/*     Spool File Name                                             */
/*     Spool File Number                                           */
/*                                                                 */
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Includes                                                        */
/*******************************************************************/
#include <stdlib.h>
#include <fstream.h>
#include <stdio.h>
#include <string.h>
#include "CWBOBJ.H"
#include "CWBSV.H"


int main (int argc, char **argv)
{
	long	rc;
	long	badrc;
	cwbSV_ErrHandle hErr;
	cwbOBJ_ObjHandle hSplf;
	char  szSysName[11];
	char	szJobName[11];
	char	szJobNumber[7];
	char	szJobUser[11];
	char	szSplfName[11];
	char	szErrText[255];
	long	lSplfNumber;
	long	lCounter;
	unsigned long	lErrTextLen;
	unsigned long	lErrCount;


	if (argc < 7)
	{
		cout << " DSPSPLF Syntax:" << endl;
		cout << "    DSPSPLF [System Name] [Job Name] [Job Number] " << endl;
		cout << "            [Job User] [Spool File Name] [Spool File Number]" << endl <<endl;
		return 20;
	}

	// Copy the command line arguments into the variables
	strcpy(szSysName, argv[1]);
	strcpy(szJobName, argv[2]);
	strcpy(szJobNumber, argv[3]);
	strcpy(szJobUser, argv[4]);
	strcpy(szSplfName, argv[5]);
	lSplfNumber = (long)atoi(argv[6]);

	// create the error handle
	if ((rc = cwbSV_CreateErrHandle(&hErr)) != 0)
	{
		cout << "Error creating an error handle.  Terminating program." << endl << endl;
		return 20;
	}

	// create a spool file handle
	rc = cwbOBJ_CreateSplFHandle(szSysName, szJobName, szJobNumber, szJobUser,
										  szSplfName, lSplfNumber, &hSplf, hErr);
	if (rc != 0)
	{
		badrc = rc;
		cout << "Error creating spool file handle.  RC = " << itoa(rc, szErrText, 10) << endl;
		rc = cwbSV_GetErrCount(hErr, &lErrCount);
		for (lCounter = 0; lCounter < lErrCount; lCounter++)
		{
			strset(szErrText, 0);
			rc = cwbSV_GetErrText(hErr, szErrText, 255, &lErrTextLen);
			cout << szErrText << endl;
		}
		return badrc;
	}

	rc=cwbOBJ_OpenSplF(hSplf, hErr);
	if (rc != 0)
	{
		badrc = rc;
		cout << "Error opening spool file.  RC = " << itoa(rc, szErrText, 10) << endl;
		rc = cwbSV_GetErrCount(hErr, &lErrCount);
		for (lCounter = 0; lCounter < lErrCount; lCounter++)
		{
			strset(szErrText, 0);
			rc = cwbSV_GetErrText(hErr, szErrText, 255, &lErrTextLen);
			cout << szErrText << endl;
		}
		return badrc;
	}

	rc=cwbOBJ_DisplaySplF(hSplf, "1", 0, hErr);
	if (rc != 0)
	{
		badrc = rc;
		cout << "Error displaying spool file.  RC = " << itoa(rc, szErrText, 10) << endl;
		rc = cwbSV_GetErrCount(hErr, &lErrCount);
		for (lCounter = 0; lCounter < lErrCount; lCounter++)
		{
			strset(szErrText, 0);
			rc = cwbSV_GetErrText(hErr, szErrText, 255, &lErrTextLen);
			cout << szErrText << endl;
		}
		return badrc;
	}

	rc = cwbOBJ_CloseSplF(hSplf, hErr);
	if (rc != 0)
	{
		badrc = rc;
		cout << "Error closing spool file.  RC = " << itoa(rc, szErrText, 10) << endl;
		rc = cwbSV_GetErrCount(hErr, &lErrCount);
		for (lCounter = 0; lCounter < lErrCount; lCounter++)
		{
			strset(szErrText, 0);
			rc = cwbSV_GetErrText(hErr, szErrText, 255, &lErrTextLen);
			cout << szErrText << endl;
		}
		return badrc;
	}


	return rc;
}